==> haskell-doctemplates-0.9-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctemplates.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doctemplates
version:              0.9
visibility:           public
id:                   doctemplates-0.9-IFHWdUG6OSe9XmFUjBo0kw
key:                  doctemplates-0.9-IFHWdUG6OSe9XmFUjBo0kw
license:              BSD-3-Clause
copyright:            2016-19 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/doctemplates#readme
synopsis:             Pandoc-style document templates
description:
    This is the text templating system used by pandoc.
    It supports variable interpolation, iteration,
    tests for non-blank values, pipes, and partials.
    Templates are rendered to doclayout Docs,
    and variable values may come from a variety of
    different sources, including aeson Values.

category:             Text
abi:                  9935b192089d23e3d17f36f98c8904e3
exposed:              True
exposed-modules:
    Text.DocTemplates Text.DocTemplates.Internal
    Text.DocTemplates.Parser

import-dirs:          /usr/lib/ghc-8.10.3/site-local/doctemplates-0.9
library-dirs:         /usr/lib/ghc-8.10.3/site-local/doctemplates-0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctemplates
hs-libraries:         HSdoctemplates-0.9-IFHWdUG6OSe9XmFUjBo0kw
depends:
    HsYAML-0.2.1.0-8i3t4EMlJpMKQ0CPnil4dd
    aeson-1.5.5.1-14rqeM2bFsAGuo3xVmo6Kw base-4.14.1.0
    containers-0.6.2.1 doclayout-0.3-Bbd4oUfivji8p2NOsDOc4V
    filepath-1.4.2.1 mtl-2.2.2 parsec-3.1.14.0
    safe-0.3.19-AfrHSVViU1189qUhjBUb5b
    scientific-0.3.6.2-CAXwEwe9ZgUFUuXUgTV0go text-1.2.4.1
    text-conversions-0.3.1-1AuoggNc989GoxG4d6GxuM
    unordered-containers-0.2.13.0-23W4q6NjyfvEwgc8XDyWoD
    vector-0.12.1.2-2wQfnsplnY91earGv9FMCk

haddock-interfaces:
    /usr/share/doc/haskell-doctemplates/html/doctemplates.haddock

haddock-html:         /usr/share/doc/haskell-doctemplates/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctemplates-0.9-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctemplates.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doctemplates
version:              0.9
visibility:           public
id:                   doctemplates-0.9-GYlO8C94GGC4x3XFwOAfyI
key:                  doctemplates-0.9-GYlO8C94GGC4x3XFwOAfyI
license:              BSD-3-Clause
copyright:            2016-19 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/doctemplates#readme
synopsis:             Pandoc-style document templates
description:
    This is the text templating system used by pandoc.
    It supports variable interpolation, iteration,
    tests for non-blank values, pipes, and partials.
    Templates are rendered to doclayout Docs,
    and variable values may come from a variety of
    different sources, including aeson Values.

category:             Text
abi:                  3382af94f2fff4b275c121fc143f43a4
exposed:              True
exposed-modules:
    Text.DocTemplates Text.DocTemplates.Internal
    Text.DocTemplates.Parser

import-dirs:          /usr/lib/ghc-8.10.3/site-local/doctemplates-0.9
library-dirs:         /usr/lib/ghc-8.10.3/site-local/doctemplates-0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctemplates
hs-libraries:         HSdoctemplates-0.9-GYlO8C94GGC4x3XFwOAfyI
depends:
    HsYAML-0.2.1.0-5Mt9c9YE0Jx1G0wzoeNb47
    aeson-1.5.5.1-AwM5PjoCXg9Gz7zfwWBIzV base-4.14.1.0
    containers-0.6.2.1 doclayout-0.3-GBbokmfvpzLANTqnFFVhC3
    filepath-1.4.2.1 mtl-2.2.2 parsec-3.1.14.0
    safe-0.3.19-AfrHSVViU1189qUhjBUb5b
    scientific-0.3.6.2-IZlBItsUzb8GTx71NeTgGr text-1.2.4.1
    text-conversions-0.3.1-C45Xli1x6p66qnrFAFvvZA
    unordered-containers-0.2.13.0-JMmUMTViutlBDpWEaCrbh4
    vector-0.12.2.0-CTKdHZ2Betb5QHFFflD8i8

haddock-interfaces:
    /usr/share/doc/haskell-doctemplates/html/doctemplates.haddock

haddock-html:         /usr/share/doc/haskell-doctemplates/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
